@@ -3,12 +3,13 @@
 # License: GNU GPL 3 or higher; http://www.gnu.org/licenses/gpl.html
 
 app_name = 'unity-mail'
-app_version = '1.1'
+app_version = '1.2'
 
 import imaplib
 import email
 import email.header
 import email.utils
+import email.errors
 import os
 import sys
 import shutil
@@ -34,7 +35,11 @@ def print_error(error):
 def decode_wrapper(header):
 	"""Decodes an Email header, returns a string"""
 	# A hack for headers without a space between decoded name and email
-	dec = email.header.decode_header(header.replace('=?=<', '=?= <'))
+	try:
+		dec = email.header.decode_header(header.replace('=?=<', '=?= <'))
+	except email.errors.HeaderParseError:
+		print_error('unity-mail: Exception in decode, skipping')
+		return header
 	parts = []
 	for dec_part in dec:
 		if dec_part[1]:
@@ -294,7 +299,7 @@ class UnityMail(object):
 			self.host.append(dict_['Host'])
 			try:
 				self.port.append(int(dict_['Port']))
-			except:
+			except ValueError:
 				# Port empty or non-integer
 				self.port.append(993)
 			self.login.append(dict_['Login'])
@@ -313,19 +318,16 @@ class UnityMail(object):
 			self.establish_connection(cn)
 		except:
 			return False
+		try:
+			res = self.mail_client[cn].login(str(self.login[cn]), str(self.passwd[cn]))
+		except imaplib.IMAP4.error as e:
+			print_error(e.args[0].decode())
+			sys.exit(
+			'unity-mail: Invalid account data provided for connection #{0}; exiting'.format(cn))
 		else:
-			try:
-				res = self.mail_client[cn].login(str(self.login[cn]), str(self.passwd[cn]))[0]
-			except imaplib.IMAP4.error as e:
-				sys.exit(e)
-			else:
-				print('unity-mail: Connection #{0} established'.format(cn))
-			if res == 'OK':
-				self.notinit[cn]=False
-				return True
-			else:
-				sys.exit(
-				'unity-mail: Invalid account data provided for connection #{0}; exiting'.format(cn))
+			print('unity-mail: Connection #{0} established'.format(cn))
+			self.notinit[cn]=False
+			return True
 	
 	def raise_error(self, index, frame):
 		raise TimeoutException('Timeout error')
@@ -355,7 +357,7 @@ class UnityMail(object):
 					msg = email.message_from_bytes(response_part[1])
 			message_id = msg['Message-Id']
 			if message_id == None:
-				message_id = str(cn)+':'+m
+				message_id = str(cn)+':'+str(m)
 			existing_message = None
 			for message in self.unread_messages:
 				if message.account_id == cn and message.message_id == message_id:
@@ -370,7 +372,7 @@ class UnityMail(object):
 					if timestamp > time.time():
 						# Message time is larger than the current one
 						timestamp = time.time()
-				except:
+				except TypeError:
 					# Failed to get time from message
 					timestamp = time.time()
 				# Number of seconds to number of microseconds
@@ -403,8 +405,8 @@ class UnityMail(object):
 	
 	def check_email(self, cn, email):
 		login, host = email.split('@')
-		return (self.login[cn]==login and
-		(self.host[cn]==host or self.host[cn]=='imap.'+host))
+		return (self.login[cn] in (login, email)
+			and self.host[cn].endswith(host))
 	
 	def get_urlid(self, cn):
 		for urlid, url in self.on_click_urls:
@@ -452,7 +454,6 @@ class UnityMail(object):
 				signal.alarm(7)
 				try:
 					self.update_single(self.cn, folder_name=folder)
-					signal.alarm(0) # Cancels alarm
 				except TimeoutException:
 					print_error(
 					'unity-mail: Timeout error occured in connection #{0}'.format(self.cn))
@@ -470,6 +471,7 @@ class UnityMail(object):
 				except KeyboardInterrupt:
 					self.notinit[self.cn]=True
 					self.handle_keyboard_interrupt()
+				signal.alarm(0) # Cancels alarm
 		if with_messagingmenu:
 			for msg in self.unread_messages:
 				# Show or hide indicator depending on it's activeness
